##  Managing To-Dos
Admins can conveniently monitor and manage all to-dos of a workspace in one place in the administration area for effective oversight and management. You can search, sort, and filter the items and modify any of the to-do items.
To access the list of to-do items, select To-Dos in the Administration area.
![To-Dos in the Administration Area](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio275376a07a441014a5aa973c479e09ca_LowRes.png)
To-Dos in the Administration Area
Click +Add Filter and select the filter criteria to filter the to-do items. You can filter by:
  * To-Do type
  * Status
  * Claimed by/Owner
  * Assignees
  * Creators
  * Fact Sheets
  * Due date
  * Creation date
  * Resolutions
  * Fact Sheet Types


You can sort the list by clicking on the column titles. Additionally, you can choose which columns to display through Manage columns.
